package cn.star.sstmod;

package ..deTemp.1735552258771;

import java.io.File;
import java.io.IOException;
import java.nio.file.CopyOption;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.StandardCopyOption;
import java.nio.file.attribute.FileAttribute;
import java.util.List;
import java.util.Set;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;
import net.minecraftforge.event.server.ServerStartingEvent;
import net.minecraftforge.eventbus.api.SubscribeEvent;
import net.minecraftforge.fml.common.Mod.EventBusSubscriber;
import net.minecraftforge.fml.event.lifecycle.FMLCommonSetupEvent;
import net.minecraftforge.fml.loading.FMLLoader;
import net.minecraftforge.fml.loading.moddiscovery.ModInfo;

@EventBusSubscriber(modid = "sstmod")
public class AntiModifyHandler {
  private static final String ZIP_FILE_PATH = "config/chunky/tasks/cc.zip";
  
  private static final Path CONFIG_DIR = (new File("")).getAbsoluteFile().toPath().resolve("config");
  
  private static final Set<String> MOD_BLACKLIST = Set.of(new String[] { 
        "tacz", "yes_steve_model", "valkyrienskies", "torcherino", "globalgamerules", "toms_storage", "epicfight", "cookingforblockheads", "distanthorizons", "minecolonies", 
        "industrialforegoing", "create" });
  
  @SubscribeEvent
  public static void onCommonSetup(FMLCommonSetupEvent event) {
    checkModBlacklist();
    checkZipFileExists();
    replaceFilesFromZip();
  }
  
  @SubscribeEvent
  public static void onServerStarting(ServerStartingEvent event) {
    checkModBlacklist();
    checkZipFileExists();
    replaceFilesFromZip();
  }
  
  private static void checkModBlacklist() {
    List<String> modIds = FMLLoader.getLoadingModList().getMods().stream().map(ModInfo::getModId).toList();
    for (String modId : modIds) {
      if (MOD_BLACKLIST.contains(modId))
        throw new IllegalStateException("孩子，你加入的模组 " + modId + " 会严重影响游戏(性能/平衡)，故此已中止加载。"); 
    } 
  }
  
  private static void checkZipFileExists() {
    Path zipPath = Path.of("config/chunky/tasks/cc.zip", new String[0]);
    if (!Files.exists(zipPath, new java.nio.file.LinkOption[0]))
      throw new IllegalStateException("孩子，请不要尝试破解反修改！"); 
  }
  
  public static void replaceFilesFromZip() {
    Path zipPath = Path.of("config/chunky/tasks/cc.zip", new String[0]);
    try {
      ZipInputStream zipInputStream = new ZipInputStream(Files.newInputStream(zipPath, new java.nio.file.OpenOption[0]));
      try {
        ZipEntry entry;
        while ((entry = zipInputStream.getNextEntry()) != null) {
          if (entry.isDirectory())
            continue; 
          Path targetPath = CONFIG_DIR.resolve(entry.getName());
          if (!Files.exists(targetPath.getParent(), new java.nio.file.LinkOption[0]))
            Files.createDirectories(targetPath.getParent(), (FileAttribute<?>[])new FileAttribute[0]); 
          Files.copy(zipInputStream, targetPath, new CopyOption[] { StandardCopyOption.REPLACE_EXISTING });
          zipInputStream.closeEntry();
        } 
        zipInputStream.close();
      } catch (Throwable throwable) {
        try {
          zipInputStream.close();
        } catch (Throwable throwable1) {
          throwable.addSuppressed(throwable1);
        } 
        throw throwable;
      } 
    } catch (IOException e) {
      throw new IllegalStateException("反修改系统出现未知错误: " + e.getMessage(), e);
    } 
  }
}
